@@ -1,6 +1,7 @@
 from astropy.table import QTable
 import astropy.units as u
 import numpy as np
+import pytest
 
 
 def test_empty_angular_resolution():
@@ -18,7 +19,8 @@ def test_empty_angular_resolution():
 
     assert np.all(np.isnan(table["angular_resolution"]))
 
-def test_angular_resolution():
+@pytest.mark.parametrize("unit", (u.deg, u.rad))
+def test_angular_resolution(unit):
     from pyirf.benchmarks import angular_resolution
 
     np.random.seed(1337)
@@ -37,10 +39,16 @@ def test_angular_resolution():
         'theta': np.abs(np.random.normal(0, true_resolution)) * u.deg
     })
 
+    events['theta'] = events['theta'].to(unit)
+
+    # add nans to test if nans are ignored
+    events["true_energy"].value[500] = np.nan
+    events["true_energy"].value[1500] = np.nan
+
     ang_res = angular_resolution(
         events,
         [1, 10, 100] * u.TeV,
-    )['angular_resolution'].quantity
+    )['angular_resolution']
 
     assert len(ang_res) == 2
     assert u.isclose(ang_res[0], TRUE_RES_1 * u.deg, rtol=0.05)
