@@ -8,10 +8,64 @@ import astropy.units as u
 from astropy.table import QTable
 
 
+#: Index returned by `calculate_bin_indices` for underflown values
+UNDERFLOW_INDEX = np.iinfo(np.int64).min
+#: Index returned by `calculate_bin_indices` for overflown values
+OVERFLOW_INDEX = np.iinfo(np.int64).max
+
+
 def bin_center(edges):
     return 0.5 * (edges[:-1] + edges[1:])
 
 
+def join_bin_lo_hi(bin_lo, bin_hi):
+    """
+    Function joins bins into lo and hi part,
+    e.g. [0, 1, 2] and [1, 2, 4] into [0, 1, 2, 4]
+    It works on multidimentional arrays as long as the binning is in the last axis
+
+    Parameters
+    ----------
+    bin_lo: np.array or u.Quantity
+        Lo bin edges array
+    bin_hi: np.array or u.Quantity
+        Hi bin edges array
+
+    Returns
+    -------
+    bins: np.array of u.Quantity
+        The joint bins
+    """
+
+    if np.allclose(bin_lo[...,1:], bin_hi[...,:-1], rtol=1.e-5):
+        last_axis=len(bin_lo.shape)-1
+        bins = np.concatenate((bin_lo, bin_hi[...,-1:]), axis=last_axis)
+        return bins
+    else:
+        raise ValueError('Not matching bin edges')
+
+
+def split_bin_lo_hi(bins):
+    """
+    Inverted function to join_bin_hi_lo,
+    e.g. it splits [0, 1, 2, 4] into [0, 1, 2] and [1, 2, 4]
+
+    Parameters
+    ----------
+    bins: np.array of u.Quantity
+        The joint bins
+
+    Returns
+    -------
+    bin_lo: np.array or u.Quantity
+        Lo bin edges array
+    bin_hi: np.array or u.Quantity
+        Hi bin edges array
+    """
+    bin_lo=bins[...,:-1]
+    bin_hi=bins[...,1:]
+    return bin_lo, bin_hi
+
 def add_overflow_bins(bins, positive=True):
     """
     Add under and overflow bins to a bin array.
@@ -50,7 +104,9 @@ def create_bins_per_decade(e_min, e_max, bins_per_decade=5):
     e_min: u.Quantity[energy]
         Minimum energy, inclusive
     e_max: u.Quantity[energy]
-        Maximum energy, exclusive
+        Maximum energy, non-inclusive
+        If the endpoint exactly matches the ``n_bins_per_decade`` requirement,
+        it will be included.
     n_bins_per_decade: int
         number of bins per decade
 
@@ -64,17 +120,21 @@ def create_bins_per_decade(e_min, e_max, bins_per_decade=5):
     log_lower = np.log10(e_min.to_value(unit))
     log_upper = np.log10(e_max.to_value(unit))
 
-    bins = 10 ** np.arange(log_lower, log_upper, 1 / bins_per_decade)
+    step = 1 / bins_per_decade
+    # include endpoint if reasonably close
+    eps = step / 10000
+    bins = 10 ** np.arange(log_lower, log_upper + eps, step)
     return u.Quantity(bins, e_min.unit, copy=False)
 
 
 def calculate_bin_indices(data, bins):
     """
     Calculate bin indices for given data array and bins.
-    Underflow will be -1 and overflow len(bins) - 1.
-    If the bis already include underflow / overflow bins, e.g.
+    Underflow will be `UNDERFLOW_INDEX` and overflow `OVERFLOW_INDEX`.
+
+    If the bins already include underflow / overflow bins, e.g.
     `bins[0] = -np.inf` and `bins[-1] = np.inf`, using the result of this
-    function will always be a valid index into the resultung histogram.
+    function will always be a valid index into the resulting histogram.
 
 
     Parameters
@@ -89,17 +149,27 @@ def calculate_bin_indices(data, bins):
     Returns
     -------
     bin_index: np.ndarray[int]
-        Indices of the histogram bin the values in data belong to
+        Indices of the histogram bin the values in data belong to.
+        Under- and overflown values will have values of `UNDERFLOW_INDEX`
+        and `OVERFLOW_INDEX` respectively.
     """
 
     if hasattr(data, "unit"):
         if not hasattr(bins, "unit"):
-            raise TypeError(f"If ``data`` is a Quantity, so must ``bin``, got {bins}")
+            raise TypeError(f"If ``data`` is a Quantity, so must ``bins``, got {bins}")
         unit = data.unit
         data = data.to_value(unit)
         bins = bins.to_value(unit)
 
-    return np.digitize(data, bins) - 1
+    n_bins = len(bins) - 1
+    idx = np.digitize(data, bins) - 1
+
+    underflow = (idx < 0)
+    overflow = (idx >= n_bins)
+    idx[underflow] = UNDERFLOW_INDEX
+    idx[overflow] = OVERFLOW_INDEX
+    valid = ~underflow & ~overflow
+    return idx, valid
 
 
 def create_histogram_table(events, bins, key="reco_energy"):
