@@ -2,7 +2,7 @@ import numpy as np
 
 from .utils import is_scalar
 
-__all__  = ['li_ma_significance']
+__all__ = ["li_ma_significance"]
 
 
 def li_ma_significance(n_on, n_off, alpha=0.2):
@@ -19,7 +19,7 @@ def li_ma_significance(n_on, n_off, alpha=0.2):
     ----------
     n_on: integer or array like
         Number of events for the on observations
-    n_off: integer of array like
+    n_off: integer or array like
         Number of events for the off observations
     alpha: float
         Ratio between the on region and the off region size or obstime.
@@ -32,8 +32,11 @@ def li_ma_significance(n_on, n_off, alpha=0.2):
 
     scalar = is_scalar(n_on)
 
-    n_on = np.array(n_on, copy=False, ndmin=1)
-    n_off = np.array(n_off, copy=False, ndmin=1)
+    # Cast everything into float64 to avoid numeric instabilties
+    # when multiplying very small and very big numbers to get t1 and t2
+    n_on = np.array(n_on, copy=False, ndmin=1, dtype=np.float64)
+    n_off = np.array(n_off, copy=False, ndmin=1, dtype=np.float64)
+    alpha = np.float64(alpha)
 
     with np.errstate(divide="ignore", invalid="ignore"):
         p_on = n_on / (n_on + n_off)
